from setuptools import setup

setup(name='dsnd_probability_rvs',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions'],
      author='Rusen Gultekin',
      author_email='rvsgltkn@hotmail.com',
      zip_safe=False)
